summaryrefslogtreecommitdiffstats
path: root/src/cfg_file.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/cfg_file.h')
-rw-r--r--src/cfg_file.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/cfg_file.h b/src/cfg_file.h
index b484d5b0d..cc31f7a0c 100644
--- a/src/cfg_file.h
+++ b/src/cfg_file.h
@@ -50,7 +50,7 @@ enum rspamd_cred_type {
};
/**
* Regexp type: /H - header, /M - mime, /U - url
*/
enum rspamd_regexp_type {
REGEXP_NONE = 0,
@@ -58,6 +58,7 @@ enum rspamd_regexp_type {
REGEXP_MIME,
REGEXP_MESSAGE,
REGEXP_URL,
+ REGEXP_RAW_HEADER,
};
/**
@@ -50,7 +50,7 @@ enum rspamd_cred_type {
};
/**
- * Regexp type: /H - header, /M - mime, /U - url
+ * Regexp type: /H - header, /M - mime, /U - url /X - raw header
*/
enum rspamd_regexp_type {